NaMaster: nmt_k_function Struct Reference

NaMaster

- Main Page
- Data Structures
- Files

- Data Structures
- Data Structure Index
- Data Fields

Data Fields
nmt_k_function Struct Reference

Flat-sky Fourier-space function. More...

`#include <namaster.h>`

## Data Fields
int | is_const
| If >0, this function is just a constant. More...
flouble | x0
| Lower edge of spline interpolation. More...
flouble | xf
| Upper edge of spline interpolation. More...
flouble | y0
| Function will take this value for x < `x0`. More...
flouble | yf
| Function will take this value for x > `xf`. More...
gsl_spline * | spl
| GSL spline interpolator. More...

## Detailed Description

Flat-sky Fourier-space function.

Unlike multipoles in harmonic space, in the case of full-sky operations, wavenumbers k in Fourier space for flat-sky fields are in general continuous variables. This structure helps define functions of these continuous variables.

## Field Documentation

int nmt_k_function::is_const

If >0, this function is just a constant.

gsl_spline* nmt_k_function::spl

GSL spline interpolator.

flouble nmt_k_function::x0

Lower edge of spline interpolation.

flouble nmt_k_function::xf

Upper edge of spline interpolation.

flouble nmt_k_function::y0

Function will take this value for x < `x0`.

flouble nmt_k_function::yf

Function will take this value for x > `xf`.

The documentation for this struct was generated from the following file:

- namaster.h